@@ -1,3 +1,5 @@
+# SPDX-FileCopyrightText: 2021 The meson-python developers
+#
 # SPDX-License-Identifier: MIT
 
 import os
@@ -18,19 +20,25 @@ def docs(session):
 
     session.install('.[docs]')
     session.chdir('docs')
-    session.run('sphinx-build', '-M', 'html', '.', '_build')
 
-    if session.posargs:
+    spelling_args = ('-b', 'spelling')
+    sphinx_build_args = ('.', '_build')
+
+    if not session.posargs:
+        # run spell-checking
+        session.run('sphinx-build', *spelling_args, *sphinx_build_args)
+        # run normal build
+        session.run('sphinx-build', *sphinx_build_args)
+    else:
         if 'serve' in session.posargs:
-            print('Launching docs at http://localhost:8000/ - use Ctrl-C to quit')
-            session.run('python', '-m', 'http.server', '8000', '-d', '_build/html')
+            session.run('sphinx-autobuild', *sphinx_build_args)
         else:
             print('Unsupported argument to docs')
 
 
 @nox.session(python='3.7')
 def mypy(session):
-    session.install('mypy==0.981')
+    session.install('mypy==0.991')
 
     session.run('mypy', '-p', 'mesonpy')
 
